==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/OwaspCrsExclusionEntryMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The variable to be excluded.
 */
public enum class OwaspCrsExclusionEntryMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable> {
    RequestHeaderNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderNames),
    RequestCookieNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieNames),
    RequestArgNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgNames),
    RequestHeaderKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderKeys),
    RequestHeaderValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderValues),
    RequestCookieKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieKeys),
    RequestCookieValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieValues),
    RequestArgKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgKeys),
    RequestArgValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgValues),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable =
        javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable):
            OwaspCrsExclusionEntryMatchVariable =
            OwaspCrsExclusionEntryMatchVariable.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/OwaspCrsExclusionEntryMatchVariable.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * The variable to be excluded.
 */
public enum class OwaspCrsExclusionEntryMatchVariable(
    public val javaValue: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable,
) : ConvertibleToJava<com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable> {
    RequestHeaderNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderNames),
    RequestCookieNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieNames),
    RequestArgNames(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgNames),
    RequestHeaderKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderKeys),
    RequestHeaderValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestHeaderValues),
    RequestCookieKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieKeys),
    RequestCookieValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestCookieValues),
    RequestArgKeys(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgKeys),
    RequestArgValues(com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable.RequestArgValues),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable =
        javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.OwaspCrsExclusionEntryMatchVariable): OwaspCrsExclusionEntryMatchVariable =
            OwaspCrsExclusionEntryMatchVariable.values().first { it.javaValue == javaType }
    }
}
